@@ -1,4 +1,5 @@
 # frozen_string_literal: true
+
 RSpec.describe HTTP::Response do
   let(:body)          { "Hello world!" }
   let(:uri)           { "http://example.com/" }
@@ -173,4 +174,13 @@ RSpec.describe HTTP::Response do
       expect(response.connection).to eq connection
     end
   end
+
+  describe "#chunked?" do
+    subject { response }
+    context "when encoding is set to chunked" do
+      let(:headers) { {"Transfer-Encoding" => "chunked"} }
+      it { is_expected.to be_chunked }
+    end
+    it { is_expected.not_to be_chunked }
+  end
 end
